ServerConf

Struct ServerConf 

pub struct ServerConf {
Show 22 fields pub admin: bool, pub name: String, pub addr: String, pub access_log: Option<String>, pub locations: Vec<String>, pub tls_cipher_list: Option<String>, pub tls_ciphersuites: Option<String>, pub tls_min_version: Option<String>, pub tls_max_version: Option<String>, pub threads: Option<usize>, pub error_template: String, pub tcp_keepalive: Option<TcpKeepalive>, pub tcp_fastopen: Option<usize>, pub reuse_port: Option<bool>, pub global_certificates: bool, pub enabled_h2: bool, pub prometheus_metrics: Option<String>, pub otlp_exporter: Option<String>, pub modules: Option<Vec<String>>, pub enable_server_timing: bool, pub downstream_read_timeout: Option<Duration>, pub downstream_write_timeout: Option<Duration>,
}

Fields

admin: boolname: Stringaddr: Stringaccess_log: Option<String>locations: Vec<String>tls_cipher_list: Option<String>tls_ciphersuites: Option<String>tls_min_version: Option<String>tls_max_version: Option<String>threads: Option<usize>error_template: Stringtcp_keepalive: Option<TcpKeepalive>tcp_fastopen: Option<usize>reuse_port: Option<bool>

Enable SO_REUSEPORT to allow multiple sockets to bind to the same address and port. This is useful for load balancing across multiple worker processes. See the man page for more information.

global_certificates: boolenabled_h2: boolprometheus_metrics: Option<String>otlp_exporter: Option<String>modules: Option<Vec<String>>enable_server_timing: booldownstream_read_timeout: Option<Duration>downstream_write_timeout: Option<Duration>